==> huaweicloudsdkbss-3.1.66-py2.py3-none-any.whl: huaweicloudsdkbss/v2/model/reclaim_to_partner_account_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ReclaimToPartnerAccountResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'trans_id': 'str'
    }

    attribute_map = {
        'trans_id': 'trans_id'
    }

    def __init__(self, trans_id=None):
        """ReclaimToPartnerAccountResponse

        The model defined in huaweicloud sdk

        :param trans_id: 事务流水ID，只有成功响应才会返回。
        :type trans_id: str
        """
        
        super(ReclaimToPartnerAccountResponse, self).__init__()

        self._trans_id = None
        self.discriminator = None

        if trans_id is not None:
            self.trans_id = trans_id

    @property
    def trans_id(self):
        """Gets the trans_id of this ReclaimToPartnerAccountResponse.

        事务流水ID，只有成功响应才会返回。

        :return: The trans_id of this ReclaimToPartnerAccountResponse.
        :rtype: str
        """
        return self._trans_id

    @trans_id.setter
    def trans_id(self, trans_id):
        """Sets the trans_id of this ReclaimToPartnerAccountResponse.

        事务流水ID，只有成功响应才会返回。

        :param trans_id: The trans_id of this ReclaimToPartnerAccountResponse.
        :type trans_id: str
        """
        self._trans_id = trans_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReclaimToPartnerAccountResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkbss-3.1.150-py2.py3-none-any.whl: huaweicloudsdkbss/v2/model/reclaim_to_partner_account_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ReclaimToPartnerAccountResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'trans_id': 'str'
    }

    attribute_map = {
        'trans_id': 'trans_id'
    }

    def __init__(self, trans_id=None):
        r"""ReclaimToPartnerAccountResponse

        The model defined in huaweicloud sdk

        :param trans_id: 事务流水ID，只有成功响应才会返回。
        :type trans_id: str
        """
        
        super(ReclaimToPartnerAccountResponse, self).__init__()

        self._trans_id = None
        self.discriminator = None

        if trans_id is not None:
            self.trans_id = trans_id

    @property
    def trans_id(self):
        r"""Gets the trans_id of this ReclaimToPartnerAccountResponse.

        事务流水ID，只有成功响应才会返回。

        :return: The trans_id of this ReclaimToPartnerAccountResponse.
        :rtype: str
        """
        return self._trans_id

    @trans_id.setter
    def trans_id(self, trans_id):
        r"""Sets the trans_id of this ReclaimToPartnerAccountResponse.

        事务流水ID，只有成功响应才会返回。

        :param trans_id: The trans_id of this ReclaimToPartnerAccountResponse.
        :type trans_id: str
        """
        self._trans_id = trans_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReclaimToPartnerAccountResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
